@@ -1,5 +1,6 @@
 import typer
-from gsc import auth, client, verifier
+import gsc
+from gsc import auth, client, verifier, setup_exercise
 
 app = typer.Typer()
 
@@ -25,16 +26,17 @@ def error(msg: str):
     raise typer.Exit(1)
 
 
-@app.command("login")
+@app.command()
 def login(email: str = typer.Option(..., prompt=True)):
     try:
         auth.login(email)
-        success("🎉 Login Success.")
+        success("Login Success.")
+
     except auth.AuthenticationError as e:
         error(str(e))
 
 
-@app.command("ping")
+@app.command()
 def ping():
     try:
         client.ping()
@@ -45,12 +47,21 @@ def ping():
         error(str(e))
 
 
-@app.command("verify")
+@app.command()
+def setup(exercise: str = typer.Argument(...)):
+    try:
+        setup_exercise.setup(exercise)
+        success("Done.")
+    except setup_exercise.SetupError as e:
+        error(str(e))
+
+
+@app.command()
 def verify():
     try:
         client.ping()
         verifier.verify()
-        success("✔️  Exercise complete!")
+        success("Exercise complete!")
     except verifier.VerifyError as e:
         error(str(e))
     except auth.AuthenticationError as e:
@@ -59,5 +70,26 @@ def verify():
         error(str(e))
 
 
+@app.callback()
+def version_callback(value: bool):
+    if value:
+        version()
+
+
+@app.command(hidden=True)
+def version():
+    typer.echo(f"gsc version: {gsc.__version__}")
+    raise typer.Exit()
+
+
+@app.callback()
+def options(version: bool = typer.Option(None, "--version", callback=version_callback)):
+    """
+    gsc is the Git for Scientists practical exercise helper.
+
+    See https://www.gitscientist.com for more.
+    """
+
+
 def main():
     app()
